@@ -275,14 +275,15 @@ class SSHConfig:
             for line in file:
                 self._line_no += 1
 
+                line = line.strip()
+                if not line or line[0] == '#':
+                    continue
+
                 try:
                     args = shlex.split(line)
                 except ValueError as exc:
                     self._error(str(exc))
 
-                if not args or args[0][:1] == '#':
-                    continue
-
                 option = args.pop(0)
                 loption = option.lower()
 
@@ -486,6 +487,7 @@ class SSHClientConfig(SSHConfig):
         ('KexAlgorithms',                   SSHConfig._set_string),
         ('MACs',                            SSHConfig._set_string),
         ('PasswordAuthentication',          SSHConfig._set_bool),
+        ('PKCS11Provider',                  SSHConfig._set_string),
         ('PreferredAuthentications',        SSHConfig._set_string),
         ('Port',                            SSHConfig._set_int),
         ('ProxyJump',                       SSHConfig._set_string),
