@@ -362,6 +362,9 @@ class _SCPSource(_SCPHandler):
         try:
             await self._make_cd_request(b'C', attrs, size, srcpath)
 
+            if self._progress_handler and size == 0:
+                self._progress_handler(srcpath, dstpath, 0, 0)
+
             while offset < size:
                 blocklen = min(size - offset, self._block_size)
 
@@ -436,6 +439,9 @@ class _SCPSource(_SCPHandler):
         """Start SCP transfer"""
 
         try:
+            if isinstance(srcpath, PurePath):
+                srcpath = str(srcpath)
+
             if isinstance(srcpath, str):
                 srcpath = srcpath.encode('utf-8')
 
@@ -479,6 +485,9 @@ class _SCPSink(_SCPHandler):
         try:
             self.send_ok()
 
+            if self._progress_handler and size == 0:
+                self._progress_handler(srcpath, dstpath, 0, 0)
+
             while offset < size:
                 blocklen = min(size - offset, self._block_size)
                 data = await self.recv_data(blocklen)
@@ -588,6 +597,9 @@ class _SCPSink(_SCPHandler):
         """Start SCP file receive"""
 
         try:
+            if isinstance(dstpath, PurePath):
+                dstpath = str(dstpath)
+
             if isinstance(dstpath, str):
                 dstpath = dstpath.encode('utf-8')
 
@@ -658,6 +670,9 @@ class _SCPCopier:
 
         offset = 0
 
+        if self._progress_handler and size == 0:
+            self._progress_handler(path, path, 0, 0)
+
         while offset < size:
             blocklen = min(size - offset, self._block_size)
             data = await self._source.recv_data(blocklen)
@@ -860,7 +875,7 @@ async def scp(srcpaths, dstpath=None, *, preserve=False, recurse=False,
 
     """
 
-    if (isinstance(srcpaths, (str, bytes)) or
+    if (isinstance(srcpaths, (str, bytes, PurePath)) or
             (isinstance(srcpaths, tuple) and len(srcpaths) == 2)):
         srcpaths = [srcpaths]
 
