@@ -72,6 +72,9 @@ _openssl_available = _openssl_version != b''
 # The openssl "-v2prf" option is only available in OpenSSL 1.0.2 or later
 _openssl_supports_v2prf = _openssl_version >= b'OpenSSL 1.0.2'
 
+# Ed25519/Ed448 support via "pkey" is only available in OpenSSL 1.1.1 or later
+_openssl_supports_pkey = _openssl_version >= b'OpenSSL 1.1.1'
+
 try:
     if sys.platform != 'win32':
         _openssh_version = run('ssh -V')
@@ -587,9 +590,13 @@ class _TestPublicKey(TempDirTestCase):
 
         format_name = 'pkcs8-%s' % fmt
 
-        if self.use_openssl: # pragma: no branch
-            run('openssl %s -pubin -in pub -inform pem -out new -outform %s' %
-                (self.keyclass, fmt))
+        if self.use_openssl:
+            if _openssl_supports_pkey:
+                run('openssl pkey -pubin -in pub -inform pem -out new '
+                    '-outform %s' % fmt)
+            else: # pragma: no cover
+                run('openssl %s -pubin -in pub -inform pem -out new '
+                    '-outform %s' % (self.keyclass, fmt))
         else: # pragma: no cover
             self.pubkey.write_public_key('new', format_name)
 
@@ -601,9 +608,13 @@ class _TestPublicKey(TempDirTestCase):
         format_name = 'pkcs8-%s' % fmt
         self.privkey.write_public_key('pubout', format_name)
 
-        if self.use_openssl: # pragma: no branch
-            run('openssl %s -pubin -in pubout -inform %s -out new '
-                '-outform pem' % (self.keyclass, fmt))
+        if self.use_openssl:
+            if _openssl_supports_pkey:
+                run('openssl pkey -pubin -in pubout -inform %s -out new '
+                    '-outform pem' % fmt)
+            else: # pragma: no cover
+                run('openssl %s -pubin -in pubout -inform %s -out new '
+                    '-outform pem' % (self.keyclass, fmt))
         else: # pragma: no cover
             pub = asyncssh.read_public_key('pubout')
             pub.write_public_key('new', format_name)
@@ -2082,12 +2093,14 @@ class TestEd25519(_TestPublicKey):
     """Test Ed25519 keys"""
 
     keyclass = 'ed25519'
-    base_format = 'openssh'
+    base_format = 'pkcs8-pem'
     private_formats = ('pkcs8', 'openssh')
     public_formats = ('pkcs8', 'openssh', 'rfc4716')
+    x509_supported = x509_available
     default_cert_version = 'ssh-ed25519-cert-v01@openssh.com'
     generate_args = (('ssh-ed25519', {}),)
-    use_openssl = False
+    use_openssh = False
+    use_openssl = _openssl_supports_pkey
 
 
 @unittest.skipUnless(ed448_available, 'ed448 not available')
@@ -2095,13 +2108,14 @@ class TestEd448(_TestPublicKey):
     """Test Ed448 keys"""
 
     keyclass = 'ed448'
-    base_format = 'openssh'
+    base_format = 'pkcs8-pem'
     private_formats = ('pkcs8', 'openssh')
     public_formats = ('pkcs8', 'openssh', 'rfc4716')
+    x509_supported = x509_available
     default_cert_version = 'ssh-ed448-cert-v01@openssh.com'
     generate_args = (('ssh-ed448', {}),)
     use_openssh = False
-    use_openssl = False
+    use_openssl = _openssl_supports_pkey
 
 
 @unittest.skipUnless(sk_available, 'security key support not available')
@@ -2141,7 +2155,6 @@ class TestSKEd25519(_TestPublicKey):
     default_cert_version = 'sk-ssh-ed25519-cert-v01@openssh.com'
     generate_args = (('sk-ssh-ed25519@openssh.com', {}),)
     use_openssh = False
-    use_openssl = False
 
     def setUp(self):
         """Set up Ed25519 security key test"""
@@ -2270,3 +2283,19 @@ class _TestPublicKeyTopLevel(TempDirTestCase):
         privkey = asyncssh.generate_private_key('ssh-rsa', 2048)
 
         self.assertIsNone(privkey.decrypt(b'', privkey.algorithm))
+
+    @unittest.skipUnless(x509_available, 'x509 not available')
+    def test_x509_certificate_hashes(self):
+        """Test X.509 certificate hash algorithms"""
+
+        privkey = asyncssh.generate_private_key('ssh-rsa')
+        pubkey = privkey.convert_to_public()
+
+        for hash_alg in ('sha1', 'sha256', 'sha512'):
+            cert = privkey.generate_x509_user_certificate(
+                pubkey, 'OU=user', hash_alg=hash_alg)
+
+            cert.write_certificate('cert', 'pem')
+
+            cert2 = asyncssh.read_certificate('cert')
+            self.assertEqual(str(cert2.subject), 'OU=user')
